@@ -1,3 +1,10 @@
+#!/usr/bin/perl
+
+BEGIN {
+  use File::Basename;
+  # Add current path to perl library search path
+  use lib dirname($0);
+}
 
 require 'module_tools.pl';
 
